@@ -42,7 +42,12 @@ class ServiceConnection:
 
     @classmethod
     def graphql_exclude_fields(cls) -> List[str]:
-        return ['schema', 'remote_service', 'remote_service_api']
+        return [
+            'schema',
+            'remote_service',
+            'remote_service_manager',
+            'remote_service_manager_api'
+        ]
 
     def __post_init__(self):
         if self.schema:
